import numpy as np
import sys
import os
sys.path.insert(0, 'code/NEST_model/')
#import testInputs3 as tp
from datetime import datetime
#current as of 23-Oct

#--------------------------------------
# SIMULATION
epochs=int(60.0*2.0) 
epoch_length=1000. 
sim_time = epochs*epoch_length 
t_sim = 1000.0  
sim_resolution = 1. 
rec_len_mm=1000.0  
rec_len_spDet=5000.0 

rec_spikes = 1.  
rec_mem = 0. 
num_threads = max_num_processes = 4


#--------------------------------------
# SYNAPSE MODELS
exc_synapse="stdp_synapse" 
inh_synapse="static_synapse"
st_synapse="static_synapse" 


#--------------------------------------
# PLASTICITY 
lmbda = 0.1    
alpha = 1.2     
tau_minus = 20.0 
tau_plus = 20.0  
mu_plus=0.0      
mu_minus=0.0
multapses = False
Wmax=10.0
W_inh = Winh = -5.0 
W_exc = W_init = 10. 

exc_plasticity= {'Wmax': Wmax, 
                'weight': W_init,
                'mu_plus': mu_plus,
                'mu_minus': mu_minus,
                'lambda': lmbda,
                'alpha': alpha,
                'tau_plus': tau_plus} 

inh_plasticity= {'weight': W_inh, 'delay': 1.0} 

static_plasticity= {'weight': 2*Wmax, 'delay': 5.0}



#--------------------------------------
# MODEL & TOPOLOGY
N = 1000         
Ne = int(0.8*N) 
Ni = N-Ne        
M = int(0.1*N)   
delay_range=[1, 21] 
V_th=30.0

V_m_range=[-65.0, -55.0] 
WtThresh = Wmax * 0.80 

exc_neuron_params = {'a': 0.02,
                    'b': 0.2,
                    'c': -65.0, 
                    'd': 8.0, 
                    'V_m': -65.0,
                    'U_m': 0.2 * -65.0, 
                    'V_th': V_th,
                    'consistent_integration': True, 
                    'tau_minus': tau_minus}

inh_neuron_params = {'a': 0.1,
                    'b': 0.2,
                    'c': -65.0,
                    'd': 2.0, 
                    'V_m': -65.0, 
                    'U_m': 0.2 * -65.0, 
                    'V_th': V_th,
                    'consistent_integration': True, 
                    'tau_minus':tau_minus}

excLIF_neuron_params = {'V_m': -70.0, 
                        'E_L': -70.0, 
                        'C_m': 250.0, 
                        'tau_m': 10.0, 
                        't_ref': 2.0,  
                        'V_th': -55.0, 
                        'V_reset': -70.0,  
                        'tau_syn_ex': 2.0, 
                        'tau_syn_in': 2.0, 
                        'I_e': 0.0}   


#--------------------------------------
# EXTERNAL STIMs
distribution='create'
poisRate=40.0                    
tStart, tEnd, gap = 1, 41, 0.40

incExc1Start=200.0
incExc1Stop=800.0
incExc1=400.0

incExc2Start=200.0
incExc2Stop=800.0
incExc2=400.0

incInhStart=720   
incInhStop=800 
incInh=20.0 

spTimes_exc1 = np.arange(incExc1Start, incExc1Stop, incExc1) 

spTimes_exc2 = np.arange(incExc2Start, incExc2Stop, incExc2) 

spTimes_inh = []



#--------------------------------------
# STAMPS/FORMATS
now = datetime.now()
Test_datetime = now.strftime("%d-%m-%Y-%H%Mhrs") 
gapNm=int(gap*100)
pltLabel=Test_datetime+'_'+str(distribution)+'Dis'+str(epochs)+'Ep'+str(gapNm)+'%_'+str(tStart)+'_'+str(tEnd)

xAxis=[0,int(epoch_length)] 

#-----------------------------------
# FILES: Input/Output

labelDat= '/home/nest/data/NEST_model/' 
label= '/home/nest/data/NEST_model/' 
fspikesIn=os.path.join(labelDat, 'spikeEvents.json')
fweightsIn=os.path.join(labelDat, 'connectivity.json') 
rstLabel='raster_'+pltLabel+'.png'
frasterOut=os.path.join(labelDat, rstLabel)
wtLabel='weights_'+pltLabel+'.png'
fweightsOut=os.path.join(labelDat, wtLabel)
psdLabel='psd_'+pltLabel+'.png'
fpsdOut=os.path.join(labelDat, psdLabel)


